@@ -18,7 +18,6 @@
 
 void QueryTest::initTestCase()
 {
-    QCoreApplication::addLibraryPath(TEST_PLUGIN_DIR);
     QStandardPaths::setTestModeEnabled(true);
     // Remove any eventual installed package globally on the system
     qputenv("XDG_DATA_DIRS", "/not/valid");
@@ -104,4 +103,18 @@ void QueryTest::queryCustomPlugin()
     QCOMPARE(KPackage::PackageLoader::self()->listPackages(QStringLiteral("Plasma/TestKPackageInternalPlasmoid")).count(), 4);
 }
 
+void QueryTest::noServiceTypesPackage()
+{
+#if QT_VERSION_MAJOR >= 6
+    QSKIP("desktop metadata files are not supported in Qt6");
+#endif
+    const int oldSize = KPackage::PackageLoader::self()->listPackages(QStringLiteral("KPackage/Generic")).size();
+
+    QVERIFY(checkedInstall(ps, QFINDTESTDATA("data/testplasmathemepackagewithoutservicetypes"), KJob::NoError));
+
+    QCOMPARE(KPackage::PackageLoader::self()->listPackages(QStringLiteral("KPackage/Generic")).size(), oldSize + 1);
+}
+
 QTEST_MAIN(QueryTest)
+
+#include "moc_querytest.cpp"
